==> zio-aws-location_2.12-5.17.130.6-sources.jar: zio/aws/location/model/GetMapTileResponse.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.location.model.primitives.Blob
import scala.jdk.CollectionConverters._
final case class GetMapTileResponse(
    blob: Option[Blob] = None,
    contentType: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.GetMapTileResponse = {
    import GetMapTileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.GetMapTileResponse
      .builder()
      .optionallyWith(
        blob.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.blob)
      .optionallyWith(contentType.map(value => value: java.lang.String))(
        _.contentType
      )
      .build()
  }
  def asReadOnly: zio.aws.location.model.GetMapTileResponse.ReadOnly =
    zio.aws.location.model.GetMapTileResponse.wrap(buildAwsValue())
}
object GetMapTileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.GetMapTileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.GetMapTileResponse =
      zio.aws.location.model.GetMapTileResponse(
        blob.map(value => value),
        contentType.map(value => value)
      )
    def blob: Option[Blob]
    def contentType: Option[String]
    def getBlob: ZIO[Any, AwsError, Blob] =
      AwsError.unwrapOptionField("blob", blob)
    def getContentType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("contentType", contentType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.GetMapTileResponse
  ) extends zio.aws.location.model.GetMapTileResponse.ReadOnly {
    override val blob: Option[Blob] = scala
      .Option(impl.blob())
      .map(value =>
        zio.aws.location.model.primitives
          .Blob(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val contentType: Option[String] =
      scala.Option(impl.contentType()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.GetMapTileResponse
  ): zio.aws.location.model.GetMapTileResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-location_2.12-5.17.166.2-sources.jar: zio/aws/location/model/GetMapTileResponse.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.location.model.primitives.Blob
import scala.jdk.CollectionConverters._
final case class GetMapTileResponse(
    blob: Optional[Blob] = Optional.Absent,
    contentType: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.GetMapTileResponse = {
    import GetMapTileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.GetMapTileResponse
      .builder()
      .optionallyWith(
        blob.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.blob)
      .optionallyWith(contentType.map(value => value: java.lang.String))(
        _.contentType
      )
      .build()
  }
  def asReadOnly: zio.aws.location.model.GetMapTileResponse.ReadOnly =
    zio.aws.location.model.GetMapTileResponse.wrap(buildAwsValue())
}
object GetMapTileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.GetMapTileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.GetMapTileResponse =
      zio.aws.location.model.GetMapTileResponse(
        blob.map(value => value),
        contentType.map(value => value)
      )
    def blob: Optional[Blob]
    def contentType: Optional[String]
    def getBlob: ZIO[Any, AwsError, Blob] =
      AwsError.unwrapOptionField("blob", blob)
    def getContentType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("contentType", contentType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.GetMapTileResponse
  ) extends zio.aws.location.model.GetMapTileResponse.ReadOnly {
    override val blob: Optional[Blob] = zio.aws.core.internal
      .optionalFromNullable(impl.blob())
      .map(value =>
        zio.aws.location.model.primitives
          .Blob(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val contentType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.GetMapTileResponse
  ): zio.aws.location.model.GetMapTileResponse.ReadOnly = new Wrapper(impl)
}
